"""Main module to run the application."""

import os
import yaml
from flask import Flask
from flask_cors import CORS

from routes.react import react_bp
from routes.api import api_bp
from routes.remote_device_wv import remotecdm_wv_bp
from routes.remote_device_pr import remotecdm_pr_bp
from routes.upload import upload_bp
from routes.user_info import user_info_bp
from routes.register import register_bp
from routes.login import login_bp
from routes.user_changes import user_change_bp
from custom_functions.prechecks.python_checks import run_python_checks
from custom_functions.prechecks.precheck import run_precheck

run_python_checks()
run_precheck()


app = Flask(__name__)
with open(
    os.path.join(os.getcwd(), "configs", "config.yaml"), "r", encoding="utf-8"
) as file:
    config = yaml.safe_load(file)
app.secret_key = config["secret_key_flask"]

CORS(app)

# Register the blueprint
app.register_blueprint(react_bp)
app.register_blueprint(api_bp)
app.register_blueprint(register_bp)
app.register_blueprint(login_bp)
app.register_blueprint(user_info_bp)
app.register_blueprint(upload_bp)
app.register_blueprint(remotecdm_wv_bp)
app.register_blueprint(remotecdm_pr_bp)
app.register_blueprint(user_change_bp)

if __name__ == "__main__":
    app.run(debug=True, host="0.0.0.0")
